@@ -1,14 +1,21 @@
-__version__ = '0.5.1'
+__version__ = '0.5.2'
 
 from docutils.parsers.rst import directives
 from docutils import nodes
 from sphinx.directives.code import CodeBlock
 from sphinx.util.docutils import SphinxDirective
 from sphinx.util.fileutil import copy_asset_file
-from sphinx.util.texescape import escape as latex_escape
 
 import os
 
+try:
+    from sphinx.util.texescape import escape as latex_escape
+except ImportError:     # ancient sphinx:
+    from sphinx.util.texescape import tex_escape_map
+
+    def latex_escape(s, latex_engine):
+        return s.translate(tex_escape_map)
+
 
 CSS_FILE = "code-tabs.css"
 JS_FILE = "code-tabs.js"
